### No Python code blocks

Example Markdown file with no Python fenced code blocks.

This is not a Python code block because there is no info_string.

```
print('Hello World- this is a non-empty code block')
```

```
Greetings World
```